@@ -50,7 +50,7 @@ class Test(Database.Base):
 class DatabaseTestCase(unittest.TestCase):
     """Test database.py"""
     def setUp(self):
-        self.database = Database('mysql://root:wendaren123@localhost/wendaren_test')
+        self.database = Database('mysql://root:wendaren123@localhost/wendaren_test?charset=utf8')
 
     def test_basic_query(self):
         """Make sure that the database is available"""
@@ -58,18 +58,18 @@ class DatabaseTestCase(unittest.TestCase):
 
     def test_init_db(self):
         """After initiation of database, there should be one table called 'test'"""
-        self.database.init_db()
+        self.database.create_tables()
         assert self.database.engine.execute('show tables').scalar() == 'test'
 
     def test_clear_db(self):
         """After clearing the database, there should be no table left"""
-        self.database.init_db()
-        self.database.clear_db()
+        self.database.create_tables()
+        self.database.drop_tables()
         assert not self.database.engine.execute('show tables').first()
 
     def tearDown(self):
         self.database.session.remove()
-        self.database.clear_db()
+        self.database.drop_tables()
 
 
 def greetings(a, b = 'default b'):
@@ -96,7 +96,7 @@ def suite():
     #suite.addTest(unittest.makeSuite(MailServerTestCase))
     suite.addTest(unittest.makeSuite(EncryptionTestCase))
     suite.addTest(unittest.makeSuite(DatabaseTestCase))
-    suite.addTest(unittest.makeSuite(InspectorTestCase))
+    #suite.addTest(unittest.makeSuite(InspectorTestCase))
     return suite
 
 
